@@ -8,11 +8,12 @@ package Text::Table::Any;
 #END IFUNBUILT
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-09'; # DATE
+our $DATE = '2022-01-07'; # DATE
 our $DIST = 'Text-Table-Any'; # DIST
-our $VERSION = '0.106'; # VERSION
+our $VERSION = '0.107'; # VERSION
 
 our @BACKENDS = qw(
+                      Term::Table
                       Term::TablePrint
                       Text::ANSITable
                       Text::ASCIITable
@@ -252,6 +253,21 @@ sub table {
             shift @$rows2;
         }
         return Term::TablePrint::print_table($rows);
+    } elsif ($backend eq 'Term::Table') {
+        require Term::Table;
+        my ($header, $data_rows);
+        if ($header_row) {
+            $header = $rows->[0];
+            $data_rows = [ @{$rows}[1 .. $#{$rows}] ];
+        } else {
+            $header = [ map {"col$_"} 0..$#{$rows->[0]} ];
+            $data_rows = $rows;
+        }
+        my $table = Term::Table->new(
+            header => $header,
+            rows   => $data_rows,
+        );
+        return join("\n", $table->render)."\n";
     } else {
         die "Unknown backend '$backend'";
     }
@@ -272,7 +288,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.106 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2021-12-09.
+This document describes version 0.107 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2022-01-07.
 
 =head1 SYNOPSIS
 
@@ -403,6 +419,8 @@ backends:
 
 =over
 
+=item * Term::Table
+
 =item * Term::TablePrint
 
 =item * Text::ANSITable
@@ -525,7 +543,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
